Obtaining embeddings from transformers
======================================

``nlpsig`` interfaces with `transformers <https://huggingface.co/docs/transformers/index>`_ and
`sentence-transformers <https://www.sbert.net/>`_ via ``nlpsig.TextEncoder`` and ``nlpsig.SentenceEncoder`` respectively.

.. automodule:: nlpsig.encode_text
   :members:
   :undoc-members:
   :show-inheritance:
